@@ -3,9 +3,7 @@ For detailed API information, see:
 https://developer.quickbase.com/
 """
 
-from distutils.log import error
 import traceback
-import requests
 from typing import Any, Dict, List
 import xml.etree.ElementTree as ET
 import pprint
